@@ -1,5 +1,5 @@
 package Crypt::PKCS11::Easy;
-$Crypt::PKCS11::Easy::VERSION = '0.161260';
+$Crypt::PKCS11::Easy::VERSION = '0.161530';
 # ABSTRACT: Wrapper around Crypt::PKCS11 to make using a HSM not suck
 
 use v5.16.3;    # CentOS7
@@ -76,7 +76,12 @@ has module_dirs => (
     is      => 'ro',
     lazy    => 1,
     isa     => ArrayRef,
-    default => sub { ['/usr/lib64/pkcs11/'] },
+    default => sub {
+        [
+            '/usr/lib64/pkcs11/', '/usr/lib/pkcs11',
+            '/usr/lib/x86_64-linux-gnu/pkcs11/'
+        ];
+    },
 );
 
 has _pkcs11 => (is => 'rwp');
@@ -334,9 +339,9 @@ sub get_slot {
 
                 # last;
             }
-            die "Unable to find slot containing token labelled '$arg{token}'"
-              unless $slot;
         }
+        die "Unable to find slot containing token labelled '$arg{token}'"
+          unless $slot;
     }
 
     # strip whitespace padding
@@ -645,7 +650,7 @@ Crypt::PKCS11::Easy - Wrapper around Crypt::PKCS11 to make using a HSM not suck
 
 =head1 VERSION
 
-version 0.161260
+version 0.161530
 
 =head1 SYNOPSIS
 
